@@ -4,7 +4,7 @@ import (
 	"io/fs"
 	"os/exec"
 
-	"github.com/rs/zerolog/log"
+	"github.com/rs/zerolog"
 	vfs "github.com/twpayne/go-vfs/v4"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
@@ -12,12 +12,14 @@ import (
 
 // A DebugSystem logs all calls to a System.
 type DebugSystem struct {
+	logger *zerolog.Logger
 	system System
 }
 
-// NewDebugSystem returns a new DebugSystem.
-func NewDebugSystem(system System) *DebugSystem {
+// NewDebugSystem returns a new DebugSystem that logs methods on system to logger.
+func NewDebugSystem(system System, logger *zerolog.Logger) *DebugSystem {
 	return &DebugSystem{
+		logger: logger,
 		system: system,
 	}
 }
@@ -25,7 +27,7 @@ func NewDebugSystem(system System) *DebugSystem {
 // Chmod implements System.Chmod.
 func (s *DebugSystem) Chmod(name AbsPath, mode fs.FileMode) error {
 	err := s.system.Chmod(name, mode)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Int("mode", int(mode)).
 		Msg("Chmod")
@@ -35,7 +37,7 @@ func (s *DebugSystem) Chmod(name AbsPath, mode fs.FileMode) error {
 // Glob implements System.Glob.
 func (s *DebugSystem) Glob(name string) ([]string, error) {
 	matches, err := s.system.Glob(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Str("name", name).
 		Strs("matches", matches).
 		Msg("Glob")
@@ -45,7 +47,7 @@ func (s *DebugSystem) Glob(name string) ([]string, error) {
 // IdempotentCmdCombinedOutput implements System.IdempotentCmdCombinedOutput.
 func (s *DebugSystem) IdempotentCmdCombinedOutput(cmd *exec.Cmd) ([]byte, error) {
 	output, err := s.system.IdempotentCmdCombinedOutput(cmd)
-	log.Err(err).
+	s.logger.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
 		Bytes("output", chezmoilog.Output(output, err)).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
@@ -56,7 +58,7 @@ func (s *DebugSystem) IdempotentCmdCombinedOutput(cmd *exec.Cmd) ([]byte, error)
 // IdempotentCmdOutput implements System.IdempotentCmdOutput.
 func (s *DebugSystem) IdempotentCmdOutput(cmd *exec.Cmd) ([]byte, error) {
 	output, err := s.system.IdempotentCmdOutput(cmd)
-	log.Err(err).
+	s.logger.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
 		Bytes("output", chezmoilog.Output(output, err)).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
@@ -67,7 +69,7 @@ func (s *DebugSystem) IdempotentCmdOutput(cmd *exec.Cmd) ([]byte, error) {
 // Link implements System.Link.
 func (s *DebugSystem) Link(oldpath, newpath AbsPath) error {
 	err := s.system.Link(oldpath, newpath)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("oldpath", oldpath).
 		Stringer("newpath", newpath).
 		Msg("Link")
@@ -77,7 +79,7 @@ func (s *DebugSystem) Link(oldpath, newpath AbsPath) error {
 // Lstat implements System.Lstat.
 func (s *DebugSystem) Lstat(name AbsPath) (fs.FileInfo, error) {
 	info, err := s.system.Lstat(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Msg("Lstat")
 	return info, err
@@ -86,7 +88,7 @@ func (s *DebugSystem) Lstat(name AbsPath) (fs.FileInfo, error) {
 // Mkdir implements System.Mkdir.
 func (s *DebugSystem) Mkdir(name AbsPath, perm fs.FileMode) error {
 	err := s.system.Mkdir(name, perm)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Int("perm", int(perm)).
 		Msg("Mkdir")
@@ -101,7 +103,7 @@ func (s *DebugSystem) RawPath(path AbsPath) (AbsPath, error) {
 // ReadDir implements System.ReadDir.
 func (s *DebugSystem) ReadDir(name AbsPath) ([]fs.DirEntry, error) {
 	dirEntries, err := s.system.ReadDir(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Msg("ReadDir")
 	return dirEntries, err
@@ -110,7 +112,7 @@ func (s *DebugSystem) ReadDir(name AbsPath) ([]fs.DirEntry, error) {
 // ReadFile implements System.ReadFile.
 func (s *DebugSystem) ReadFile(name AbsPath) ([]byte, error) {
 	data, err := s.system.ReadFile(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Bytes("data", chezmoilog.Output(data, err)).
 		Msg("ReadFile")
@@ -120,7 +122,7 @@ func (s *DebugSystem) ReadFile(name AbsPath) ([]byte, error) {
 // Readlink implements System.Readlink.
 func (s *DebugSystem) Readlink(name AbsPath) (string, error) {
 	linkname, err := s.system.Readlink(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Str("linkname", linkname).
 		Msg("Readlink")
@@ -130,7 +132,7 @@ func (s *DebugSystem) Readlink(name AbsPath) (string, error) {
 // RemoveAll implements System.RemoveAll.
 func (s *DebugSystem) RemoveAll(name AbsPath) error {
 	err := s.system.RemoveAll(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Msg("RemoveAll")
 	return err
@@ -139,7 +141,7 @@ func (s *DebugSystem) RemoveAll(name AbsPath) error {
 // Rename implements System.Rename.
 func (s *DebugSystem) Rename(oldpath, newpath AbsPath) error {
 	err := s.system.Rename(oldpath, newpath)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("oldpath", oldpath).
 		Stringer("newpath", newpath).
 		Msg("Rename")
@@ -149,7 +151,7 @@ func (s *DebugSystem) Rename(oldpath, newpath AbsPath) error {
 // RunCmd implements System.RunCmd.
 func (s *DebugSystem) RunCmd(cmd *exec.Cmd) error {
 	err := s.system.RunCmd(cmd)
-	log.Err(err).
+	s.logger.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("RunCmd")
@@ -159,7 +161,7 @@ func (s *DebugSystem) RunCmd(cmd *exec.Cmd) error {
 // RunIdempotentCmd implements System.RunIdempotentCmd.
 func (s *DebugSystem) RunIdempotentCmd(cmd *exec.Cmd) error {
 	err := s.system.RunIdempotentCmd(cmd)
-	log.Err(err).
+	s.logger.Err(err).
 		EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: cmd}).
 		EmbedObject(chezmoilog.OSExecExitErrorLogObject{Err: err}).
 		Msg("RunIdempotentCmd")
@@ -169,7 +171,7 @@ func (s *DebugSystem) RunIdempotentCmd(cmd *exec.Cmd) error {
 // RunScript implements System.RunScript.
 func (s *DebugSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, interpreter *Interpreter) error {
 	err := s.system.RunScript(scriptname, dir, data, interpreter)
-	log.Err(err).
+	s.logger.Err(err).
 		Str("scriptname", string(scriptname)).
 		Stringer("dir", dir).
 		Bytes("data", chezmoilog.Output(data, err)).
@@ -182,7 +184,7 @@ func (s *DebugSystem) RunScript(scriptname RelPath, dir AbsPath, data []byte, in
 // Stat implements System.Stat.
 func (s *DebugSystem) Stat(name AbsPath) (fs.FileInfo, error) {
 	info, err := s.system.Stat(name)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Msg("Stat")
 	return info, err
@@ -196,7 +198,7 @@ func (s *DebugSystem) UnderlyingFS() vfs.FS {
 // WriteFile implements System.WriteFile.
 func (s *DebugSystem) WriteFile(name AbsPath, data []byte, perm fs.FileMode) error {
 	err := s.system.WriteFile(name, data, perm)
-	log.Err(err).
+	s.logger.Err(err).
 		Stringer("name", name).
 		Bytes("data", chezmoilog.Output(data, err)).
 		Int("perm", int(perm)).
@@ -207,7 +209,7 @@ func (s *DebugSystem) WriteFile(name AbsPath, data []byte, perm fs.FileMode) err
 // WriteSymlink implements System.WriteSymlink.
 func (s *DebugSystem) WriteSymlink(oldname string, newname AbsPath) error {
 	err := s.system.WriteSymlink(oldname, newname)
-	log.Err(err).
+	s.logger.Err(err).
 		Str("oldname", oldname).
 		Stringer("newname", newname).
 		Msg("WriteSymlink")
