@@ -18,6 +18,16 @@ const (
 	boolModifierClear          boolModifier = -1
 )
 
+type conditionModifier int
+
+const (
+	conditionModifierLeaveUnchanged conditionModifier = iota
+	conditionModifierClearOnce
+	conditionModifierSetOnce
+	conditionModifierClearOnChange
+	conditionModifierSetOnChange
+)
+
 type orderModifier int
 
 const (
@@ -29,11 +39,11 @@ const (
 )
 
 type attrModifier struct {
+	condition  conditionModifier
 	empty      boolModifier
 	encrypted  boolModifier
 	exact      boolModifier
 	executable boolModifier
-	once       boolModifier
 	order      orderModifier
 	private    boolModifier
 	readOnly   boolModifier
@@ -49,6 +59,7 @@ func (c *Config) newChattrCmd() *cobra.Command {
 		"exact",
 		"executable", "x",
 		"once", "o",
+		"onchange",
 		"private", "p",
 		"readonly", "r",
 		"template", "t",
@@ -141,25 +152,49 @@ func (m boolModifier) modify(b bool) bool {
 	}
 }
 
+// modify returns the modified value of condition.
+func (m conditionModifier) modify(condition chezmoi.ScriptCondition) chezmoi.ScriptCondition {
+	switch m {
+	case conditionModifierLeaveUnchanged:
+		return condition
+	case conditionModifierClearOnce:
+		if condition == chezmoi.ScriptConditionOnce {
+			return chezmoi.ScriptConditionAlways
+		}
+		return condition
+	case conditionModifierSetOnce:
+		return chezmoi.ScriptConditionOnce
+	case conditionModifierClearOnChange:
+		if condition == chezmoi.ScriptConditionOnChange {
+			return chezmoi.ScriptConditionAlways
+		}
+		return condition
+	case conditionModifierSetOnChange:
+		return chezmoi.ScriptConditionOnChange
+	default:
+		panic(fmt.Sprintf("%d: unknown order modifier", m))
+	}
+}
+
 // modify returns the modified value of order.
-func (m orderModifier) modify(order int) int {
+func (m orderModifier) modify(order chezmoi.ScriptOrder) chezmoi.ScriptOrder {
 	switch m {
 	case orderModifierSetBefore:
-		return -1
+		return chezmoi.ScriptOrderBefore
 	case orderModifierClearBefore:
-		if order < 0 {
-			return 0
+		if order == chezmoi.ScriptOrderBefore {
+			return chezmoi.ScriptOrderDuring
 		}
 		return order
 	case orderModifierLeaveUnchanged:
 		return order
 	case orderModifierClearAfter:
-		if order > 0 {
-			return 0
+		if order == chezmoi.ScriptOrderAfter {
+			return chezmoi.ScriptOrderDuring
 		}
 		return order
 	case orderModifierSetAfter:
-		return 1
+		return chezmoi.ScriptOrderAfter
 	default:
 		panic(fmt.Sprintf("%d: unknown order modifier", m))
 	}
@@ -217,7 +252,19 @@ func parseAttrModifier(s string) (*attrModifier, error) {
 		case "executable", "x":
 			am.executable = bm
 		case "once", "o":
-			am.once = bm
+			switch bm {
+			case boolModifierClear:
+				am.condition = conditionModifierClearOnce
+			case boolModifierSet:
+				am.condition = conditionModifierSetOnce
+			}
+		case "onchange":
+			switch bm {
+			case boolModifierClear:
+				am.condition = conditionModifierClearOnChange
+			case boolModifierSet:
+				am.condition = conditionModifierSetOnChange
+			}
 		case "private", "p":
 			am.private = bm
 		case "readonly", "r":
@@ -278,7 +325,7 @@ func (am *attrModifier) modifyFileAttr(fileAttr chezmoi.FileAttr) chezmoi.FileAt
 		return chezmoi.FileAttr{
 			TargetName: fileAttr.TargetName,
 			Type:       chezmoi.SourceFileTypeScript,
-			Once:       am.once.modify(fileAttr.Once),
+			Condition:  am.condition.modify(fileAttr.Condition),
 			Order:      am.order.modify(fileAttr.Order),
 		}
 	case chezmoi.SourceFileTypeSymlink:
