@@ -25,6 +25,7 @@ import (
 
 	"github.com/Masterminds/sprig/v3"
 	"github.com/coreos/go-semver/semver"
+	gogit "github.com/go-git/go-git/v5"
 	"github.com/go-git/go-git/v5/plumbing/format/diff"
 	"github.com/google/gops/agent"
 	"github.com/mitchellh/mapstructure"
@@ -44,6 +45,14 @@ import (
 	"github.com/twpayne/chezmoi/v2/internal/git"
 )
 
+const (
+	logComponentKey                  = "component"
+	logComponentValueEncryption      = "encryption"
+	logComponentValuePersistentState = "persistentState"
+	logComponentValueSourceState     = "sourceState"
+	logComponentValueSystem          = "system"
+)
+
 type purgeOptions struct {
 	binary bool
 }
@@ -124,6 +133,7 @@ type Config struct {
 	_import         importCmdConfig
 	init            initCmdConfig
 	managed         managedCmdConfig
+	mergeAll        mergeAllCmdConfig
 	purge           purgeCmdConfig
 	reAdd           reAddCmdConfig
 	remove          removeCmdConfig
@@ -147,6 +157,7 @@ type Config struct {
 	sourceSystem      chezmoi.System
 	destSystem        chezmoi.System
 	persistentState   chezmoi.PersistentState
+	logger            *zerolog.Logger
 
 	// Computed configuration.
 	homeDirAbsPath chezmoi.AbsPath
@@ -326,6 +337,9 @@ func newConfig(options ...configOption) (*Config, error) {
 			exclude: chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include: chezmoi.NewEntryTypeSet(chezmoi.EntryTypeDirs | chezmoi.EntryTypeFiles | chezmoi.EntryTypeSymlinks | chezmoi.EntryTypeEncrypted),
 		},
+		mergeAll: mergeAllCmdConfig{
+			recursive: true,
+		},
 		reAdd: reAddCmdConfig{
 			exclude:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesNone),
 			include:   chezmoi.NewEntryTypeSet(chezmoi.EntryTypesAll),
@@ -374,6 +388,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"bitwarden":                c.bitwardenTemplateFunc,
 		"bitwardenAttachment":      c.bitwardenAttachmentTemplateFunc,
 		"bitwardenFields":          c.bitwardenFieldsTemplateFunc,
+		"decrypt":                  c.decryptTemplateFunc,
+		"encrypt":                  c.encryptTemplateFunc,
 		"gitHubKeys":               c.gitHubKeysTemplateFunc,
 		"gopass":                   c.gopassTemplateFunc,
 		"gopassRaw":                c.gopassRawTemplateFunc,
@@ -553,7 +569,7 @@ func (c *Config) close() error {
 	var err error
 	for _, tempDirAbsPath := range c.tempDirs {
 		err2 := os.RemoveAll(tempDirAbsPath.String())
-		log.Err(err2).
+		c.logger.Err(err2).
 			Stringer("tempDir", tempDirAbsPath).
 			Msg("RemoveAll")
 		err = multierr.Append(err, err2)
@@ -671,15 +687,15 @@ func (c *Config) createConfigFile(filename chezmoi.RelPath, data []byte) ([]byte
 		return nil, err
 	}
 
-	sb := strings.Builder{}
+	builder := strings.Builder{}
 	templateData := c.defaultTemplateData()
 	if c.init.data {
 		chezmoi.RecursiveMerge(templateData, c.Data)
 	}
-	if err = t.Execute(&sb, templateData); err != nil {
+	if err = t.Execute(&builder, templateData); err != nil {
 		return nil, err
 	}
-	return []byte(sb.String()), nil
+	return []byte(builder.String()), nil
 }
 
 // defaultConfigFile returns the default config file according to the XDG Base
@@ -710,7 +726,7 @@ func (c *Config) defaultConfigFile(fileSystem vfs.Stater, bds *xdg.BaseDirectory
 // has changed since chezmoi last wrote it then it prompts the user for the
 // action to take.
 func (c *Config) defaultPreApplyFunc(targetRelPath chezmoi.RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *chezmoi.EntryState) error {
-	log.Info().
+	c.logger.Info().
 		Stringer("targetRelPath", targetRelPath).
 		Object("targetEntryState", targetEntryState).
 		Object("lastWrittenEntryState", lastWrittenEntryState).
@@ -730,7 +746,6 @@ func (c *Config) defaultPreApplyFunc(targetRelPath chezmoi.RelPath, targetEntryS
 		return nil
 	}
 
-	// LATER add merge option
 	var choices []string
 	actualContents := actualEntryState.Contents()
 	targetContents := targetEntryState.Contents()
@@ -817,20 +832,20 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 			if rawGroup, err := user.LookupGroupId(currentUser.Gid); err == nil {
 				group = rawGroup.Name
 			} else {
-				log.Info().
+				c.logger.Info().
 					Str("gid", currentUser.Gid).
 					Err(err).
 					Msg("user.LookupGroupId")
 			}
 		}
 	} else {
-		log.Info().
+		c.logger.Info().
 			Err(err).
 			Msg("user.Current")
 		var ok bool
 		username, ok = os.LookupEnv("USER")
 		if !ok {
-			log.Info().
+			c.logger.Info().
 				Str("key", "USER").
 				Bool("ok", ok).
 				Msg("os.LookupEnv")
@@ -843,14 +858,14 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 	if rawHostname, err := os.Hostname(); err == nil {
 		hostname = strings.SplitN(rawHostname, ".", 2)[0]
 	} else {
-		log.Info().
+		c.logger.Info().
 			Err(err).
 			Msg("os.Hostname")
 	}
 
 	kernel, err := chezmoi.Kernel(c.fileSystem)
 	if err != nil {
-		log.Info().
+		c.logger.Info().
 			Err(err).
 			Msg("chezmoi.Kernel")
 	}
@@ -859,7 +874,7 @@ func (c *Config) defaultTemplateData() map[string]interface{} {
 	if rawOSRelease, err := chezmoi.OSRelease(c.baseSystem); err == nil {
 		osRelease = upperSnakeCaseToCamelCaseMap(rawOSRelease)
 	} else {
-		log.Info().
+		c.logger.Info().
 			Err(err).
 			Msg("chezmoi.OSRelease")
 	}
@@ -948,8 +963,8 @@ func (c *Config) destAbsPathInfos(sourceState *chezmoi.SourceState, args []strin
 // diffFile outputs the diff between fromData and fromMode and toData and toMode
 // at path.
 func (c *Config) diffFile(path chezmoi.RelPath, fromData []byte, fromMode fs.FileMode, toData []byte, toMode fs.FileMode) error {
-	var sb strings.Builder
-	unifiedEncoder := diff.NewUnifiedEncoder(&sb, diff.DefaultContextLines)
+	builder := strings.Builder{}
+	unifiedEncoder := diff.NewUnifiedEncoder(&builder, diff.DefaultContextLines)
 	color := c.Color.Value(c.colorAutoFunc)
 	if color {
 		unifiedEncoder.SetColor(diff.NewColorConfig())
@@ -961,71 +976,7 @@ func (c *Config) diffFile(path chezmoi.RelPath, fromData []byte, fromMode fs.Fil
 	if err := unifiedEncoder.Encode(diffPatch); err != nil {
 		return err
 	}
-	return c.pageOutputString(sb.String(), c.Diff.Pager)
-}
-
-// doPurge is the core purge functionality. It removes all files and directories
-// associated with chezmoi.
-func (c *Config) doPurge(purgeOptions *purgeOptions) error {
-	if c.persistentState != nil {
-		if err := c.persistentState.Close(); err != nil {
-			return err
-		}
-	}
-
-	persistentStateFileAbsPath, err := c.persistentStateFile()
-	if err != nil {
-		return err
-	}
-	absPaths := []chezmoi.AbsPath{
-		c.CacheDirAbsPath,
-		c.configFileAbsPath.Dir(),
-		c.configFileAbsPath,
-		persistentStateFileAbsPath,
-		c.WorkingTreeAbsPath,
-		c.SourceDirAbsPath,
-	}
-	if purgeOptions != nil && purgeOptions.binary {
-		executable, err := os.Executable()
-		// Special case: do not purge the binary if it is a test binary created
-		// by go test as this would break later tests.
-		if err == nil && !strings.Contains(executable, "test") {
-			absPaths = append(absPaths, chezmoi.NewAbsPath(executable))
-		}
-	}
-
-	// Remove all paths that exist.
-	for _, absPath := range absPaths {
-		switch _, err := c.destSystem.Stat(absPath); {
-		case errors.Is(err, fs.ErrNotExist):
-			continue
-		case err != nil:
-			return err
-		}
-
-		if !c.force {
-			switch choice, err := c.promptChoice(fmt.Sprintf("Remove %s", absPath), yesNoAllQuit); {
-			case err != nil:
-				return err
-			case choice == "yes":
-			case choice == "no":
-				continue
-			case choice == "all":
-				c.force = true
-			case choice == "quit":
-				return nil
-			}
-		}
-
-		switch err := c.destSystem.RemoveAll(absPath); {
-		case errors.Is(err, fs.ErrPermission):
-			continue
-		case err != nil:
-			return err
-		}
-	}
-
-	return nil
+	return c.pageOutputString(builder.String(), c.Diff.Pager)
 }
 
 // editor returns the path to the user's editor and any extra arguments.
@@ -1292,6 +1243,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		c.newInternalTestCmd(),
 		c.newManagedCmd(),
 		c.newMergeCmd(),
+		c.newMergeAllCmd(),
 		c.newPurgeCmd(),
 		c.newReAddCmd(),
 		c.newRemoveCmd(),
@@ -1314,6 +1266,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 
 // newSourceState returns a new SourceState with options.
 func (c *Config) newSourceState(ctx context.Context, options ...chezmoi.SourceStateOption) (*chezmoi.SourceState, error) {
+	sourceStateLogger := c.logger.With().Str(logComponentKey, logComponentValueSourceState).Logger()
 	s := chezmoi.NewSourceState(append([]chezmoi.SourceStateOption{
 		chezmoi.WithBaseSystem(c.baseSystem),
 		chezmoi.WithCacheDir(c.CacheDirAbsPath),
@@ -1321,6 +1274,7 @@ func (c *Config) newSourceState(ctx context.Context, options ...chezmoi.SourceSt
 		chezmoi.WithDestDir(c.DestDirAbsPath),
 		chezmoi.WithEncryption(c.encryption),
 		chezmoi.WithInterpreters(c.Interpreters),
+		chezmoi.WithLogger(&sourceStateLogger),
 		chezmoi.WithMode(c.Mode),
 		chezmoi.WithPriorityTemplateData(c.Data),
 		chezmoi.WithSourceDir(c.SourceDirAbsPath),
@@ -1458,9 +1412,10 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	} else {
 		zerolog.SetGlobalLevel(zerolog.Disabled)
 	}
+	c.logger = &log.Logger
 
 	// Log basic information.
-	log.Info().
+	c.logger.Info().
 		Object("version", c.versionInfo).
 		Strs("args", args).
 		Str("goVersion", runtime.Version()).
@@ -1470,7 +1425,8 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		chezmoi.RealSystemWithSafe(c.Safe),
 	)
 	if c.debug {
-		c.baseSystem = chezmoi.NewDebugSystem(c.baseSystem)
+		systemLogger := c.logger.With().Str(logComponentKey, logComponentValueSystem).Logger()
+		c.baseSystem = chezmoi.NewDebugSystem(c.baseSystem, &systemLogger)
 	}
 
 	// Set up the persistent state.
@@ -1518,7 +1474,8 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		c.persistentState = chezmoi.NullPersistentState{}
 	}
 	if c.debug && c.persistentState != nil {
-		c.persistentState = chezmoi.NewDebugPersistentState(c.persistentState)
+		persistentStateLogger := c.logger.With().Str(logComponentKey, logComponentValuePersistentState).Logger()
+		c.persistentState = chezmoi.NewDebugPersistentState(c.persistentState, &persistentStateLogger)
 	}
 
 	// Set up the source and destination systems.
@@ -1566,7 +1523,8 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		return fmt.Errorf("%s: unknown encryption", c.Encryption)
 	}
 	if c.debug {
-		c.encryption = chezmoi.NewDebugEncryption(c.encryption)
+		encryptionLogger := c.logger.With().Str(logComponentKey, logComponentValueEncryption).Logger()
+		c.encryption = chezmoi.NewDebugEncryption(c.encryption, &encryptionLogger)
 	}
 
 	// Create the config directory if needed.
@@ -1603,13 +1561,13 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		workingTreeAbsPath := c.SourceDirAbsPath
 	FOR:
 		for {
-			if info, err := c.baseSystem.Stat(workingTreeAbsPath.Join(".git")); err == nil && info.IsDir() {
+			if info, err := c.baseSystem.Stat(workingTreeAbsPath.Join(gogit.GitDirName)); err == nil && info.IsDir() {
 				c.WorkingTreeAbsPath = workingTreeAbsPath
 				break FOR
 			}
 			prevWorkingTreeDirAbsPath := workingTreeAbsPath
 			workingTreeAbsPath = workingTreeAbsPath.Dir()
-			if workingTreeAbsPath.Len() >= prevWorkingTreeDirAbsPath.Len() {
+			if workingTreeAbsPath == c.homeDirAbsPath || workingTreeAbsPath.Len() >= prevWorkingTreeDirAbsPath.Len() {
 				c.WorkingTreeAbsPath = c.SourceDirAbsPath
 				break FOR
 			}
@@ -1833,7 +1791,7 @@ func (c *Config) tempDir(key string) (chezmoi.AbsPath, error) {
 		return tempDirAbsPath, nil
 	}
 	tempDir, err := os.MkdirTemp("", key)
-	log.Err(err).
+	c.logger.Err(err).
 		Str("tempDir", tempDir).
 		Msg("MkdirTemp")
 	if err != nil {
