@@ -9,6 +9,7 @@ import (
 	"net/http"
 	"net/http/httptest"
 	"os"
+	"os/exec"
 	"path"
 	"path/filepath"
 	"regexp"
@@ -217,8 +218,7 @@ func cmdMkFile(ts *testscript.TestScript, neg bool, args []string) {
 	}
 	for _, arg := range args {
 		filename := ts.MkAbs(arg)
-		_, err := os.Lstat(filename)
-		switch {
+		switch _, err := os.Lstat(filename); {
 		case err == nil:
 			ts.Fatalf("%s: already exists", arg)
 		case !errors.Is(err, fs.ErrNotExist):
@@ -241,20 +241,20 @@ func cmdMkAgeConfig(ts *testscript.TestScript, neg bool, args []string) {
 	symmetric := len(args) == 1 && args[0] == "-symmetric"
 	homeDir := ts.Getenv("HOME")
 	ts.Check(os.MkdirAll(homeDir, 0o777))
-	privateKeyFile := filepath.Join(homeDir, "key.txt")
-	publicKey, _, err := chezmoitest.AgeGenerateKey(ts.MkAbs(privateKeyFile))
+	identityFile := filepath.Join(homeDir, "key.txt")
+	recipient, err := chezmoitest.AgeGenerateKey(ts.MkAbs(identityFile))
 	ts.Check(err)
 	configFile := filepath.Join(homeDir, ".config", "chezmoi", "chezmoi.toml")
 	ts.Check(os.MkdirAll(filepath.Dir(configFile), 0o777))
 	lines := []string{
 		`encryption = "age"`,
 		`[age]`,
-		`    identity = ` + strconv.Quote(privateKeyFile),
+		`    identity = ` + strconv.Quote(identityFile),
 	}
 	if symmetric {
 		lines = append(lines, `    symmetric = true`)
 	} else {
-		lines = append(lines, `    recipient = `+strconv.Quote(publicKey))
+		lines = append(lines, `    recipient = `+strconv.Quote(recipient))
 	}
 	ts.Check(os.WriteFile(configFile, []byte(chezmoitest.JoinLines(lines...)), 0o666))
 }
@@ -308,7 +308,7 @@ func cmdMkGPGConfig(ts *testscript.TestScript, neg bool, args []string) {
 		ts.Check(os.Chmod(gpgHomeDir, 0o700))
 	}
 
-	command, err := chezmoitest.GPGCommand()
+	command, err := exec.LookPath("gpg")
 	ts.Check(err)
 
 	key, passphrase, err := chezmoitest.GPGGenerateKey(command, gpgHomeDir)
@@ -613,18 +613,18 @@ func setup(env *testscript.Env) error {
 
 // unix2DOS returns data with UNIX line endings converted to DOS line endings.
 func unix2DOS(data []byte) ([]byte, error) {
-	sb := strings.Builder{}
-	s := bufio.NewScanner(bytes.NewReader(data))
-	for s.Scan() {
-		if _, err := sb.Write(s.Bytes()); err != nil {
+	builder := strings.Builder{}
+	scanner := bufio.NewScanner(bytes.NewReader(data))
+	for scanner.Scan() {
+		if _, err := builder.Write(scanner.Bytes()); err != nil {
 			return nil, err
 		}
-		if _, err := sb.WriteString("\r\n"); err != nil {
+		if _, err := builder.WriteString("\r\n"); err != nil {
 			return nil, err
 		}
 	}
-	if err := s.Err(); err != nil {
+	if err := scanner.Err(); err != nil {
 		return nil, err
 	}
-	return []byte(sb.String()), nil
+	return []byte(builder.String()), nil
 }
