@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/rs/zerolog/log"
 	"github.com/spf13/cobra"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
@@ -40,10 +39,10 @@ func (c *Config) newStatusCmd() *cobra.Command {
 }
 
 func (c *Config) runStatusCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
-	sb := strings.Builder{}
+	builder := strings.Builder{}
 	dryRunSystem := chezmoi.NewDryRunSystem(c.destSystem)
-	statusCmdPreApplyFunc := func(targetRelPath chezmoi.RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *chezmoi.EntryState) error {
-		log.Info().
+	preApplyFunc := func(targetRelPath chezmoi.RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *chezmoi.EntryState) error {
+		c.logger.Info().
 			Stringer("targetRelPath", targetRelPath).
 			Object("targetEntryState", targetEntryState).
 			Object("lastWrittenEntryState", lastWrittenEntryState).
@@ -62,7 +61,7 @@ func (c *Config) runStatusCmd(cmd *cobra.Command, args []string, sourceState *ch
 			y = statusRune(actualEntryState, targetEntryState)
 		}
 		if x != ' ' || y != ' ' {
-			fmt.Fprintf(&sb, "%c%c %s\n", x, y, targetRelPath)
+			fmt.Fprintf(&builder, "%c%c %s\n", x, y, targetRelPath)
 		}
 		return chezmoi.Skip
 	}
@@ -71,11 +70,11 @@ func (c *Config) runStatusCmd(cmd *cobra.Command, args []string, sourceState *ch
 		init:         c.status.init,
 		recursive:    c.status.recursive,
 		umask:        c.Umask,
-		preApplyFunc: statusCmdPreApplyFunc,
+		preApplyFunc: preApplyFunc,
 	}); err != nil {
 		return err
 	}
-	return c.writeOutputString(sb.String())
+	return c.writeOutputString(builder.String())
 }
 
 func statusRune(fromState, toState *chezmoi.EntryState) rune {
